You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jb...@apache.org on 2006/11/19 17:03:52 UTC

svn commit: r476842 - in /incubator/tuscany/branches/sca-java-M2/sca: kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/ kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/ kernel/core/src/test/java/org/...

Author: jboynes
Date: Sun Nov 19 08:03:50 2006
New Revision: 476842

URL: http://svn.apache.org/viewvc?view=rev&rev=476842
Log:
add missing headers reported by RAT

Modified:
    incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/AbstractOperationOutboundInvocationHandler.java
    incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/CompositeReferenceCallbackTargetInvokerInvocationExceptionTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/loader/JNDIPropertyFactoryTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractInboundInvocationHandlerTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractOutboundInvocationHandlerTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java
    incubator/tuscany/branches/sca-java-M2/sca/runtime/osgi/src/main/java/org/apache/tuscany/osgi/util/ClassloaderHook.java
    incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp-host/src/main/java/org/apache/tuscany/runtime/webapp/InvalidCompositePath.java
    incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/main/java/org/apache/tuscany/runtime/webapp/Constants.java
    incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/test/java/org/apache/tuscany/runtime/webapp/TuscanySessionListenerTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/services/bindings/binding.celtix/.pmd
    incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/apache/tuscany/container/spring/impl/SpringInterceptor.java
    incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/springframework/sca/ScaAdapterAware.java
    incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/impl/SpringCompositeComponentTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/integration/BootstrapTestCase.java
    incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/mock/TestReference.java
    incubator/tuscany/branches/sca-java-M2/sca/services/databinding/databinding-sdo/pom.xml
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/Bootstrapper.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingReference.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingRuntimeException.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestInvoker.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBinding.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingBuilder.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingLoader.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingReference.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingService.java
    incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketInvoker.java

Modified: incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/AbstractOperationOutboundInvocationHandler.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/AbstractOperationOutboundInvocationHandler.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/AbstractOperationOutboundInvocationHandler.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/main/java/org/apache/tuscany/core/implementation/composite/AbstractOperationOutboundInvocationHandler.java Sun Nov 19 08:03:50 2006
@@ -1,8 +1,30 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.core.implementation.composite;
 
 import org.apache.tuscany.spi.model.Operation;
 import org.apache.tuscany.spi.wire.AbstractOutboundInvocationHandler;
 
+/**
+ *
+ * @version $Rev$ $Date$
+ */
 public abstract class AbstractOperationOutboundInvocationHandler
     extends AbstractOutboundInvocationHandler {
 

Modified: incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/CompositeReferenceCallbackTargetInvokerInvocationExceptionTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/CompositeReferenceCallbackTargetInvokerInvocationExceptionTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/CompositeReferenceCallbackTargetInvokerInvocationExceptionTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/implementation/composite/CompositeReferenceCallbackTargetInvokerInvocationExceptionTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.core.implementation.composite;
 
 import java.lang.reflect.Type;

Modified: incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/loader/JNDIPropertyFactoryTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/loader/JNDIPropertyFactoryTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/loader/JNDIPropertyFactoryTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/kernel/core/src/test/java/org/apache/tuscany/core/loader/JNDIPropertyFactoryTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.core.loader;
 
 import java.lang.reflect.Type;

Modified: incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractInboundInvocationHandlerTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractInboundInvocationHandlerTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractInboundInvocationHandlerTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractInboundInvocationHandlerTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.spi.wire;
 
 import java.lang.reflect.Array;

Modified: incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractOutboundInvocationHandlerTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractOutboundInvocationHandlerTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractOutboundInvocationHandlerTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/kernel/spi/src/test/java/org/apache/tuscany/spi/wire/AbstractOutboundInvocationHandlerTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.spi.wire;
 
 import java.lang.reflect.Array;

Modified: incubator/tuscany/branches/sca-java-M2/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/runtime/osgi/src/main/java/org/apache/tuscany/osgi/util/ClassloaderHook.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/runtime/osgi/src/main/java/org/apache/tuscany/osgi/util/ClassloaderHook.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.osgi.util;
 
 import java.lang.reflect.InvocationTargetException;

Modified: incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp-host/src/main/java/org/apache/tuscany/runtime/webapp/InvalidCompositePath.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp-host/src/main/java/org/apache/tuscany/runtime/webapp/InvalidCompositePath.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp-host/src/main/java/org/apache/tuscany/runtime/webapp/InvalidCompositePath.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp-host/src/main/java/org/apache/tuscany/runtime/webapp/InvalidCompositePath.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.runtime.webapp;
 
 import org.apache.tuscany.api.TuscanyException;

Modified: incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/main/java/org/apache/tuscany/runtime/webapp/Constants.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/main/java/org/apache/tuscany/runtime/webapp/Constants.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/main/java/org/apache/tuscany/runtime/webapp/Constants.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/main/java/org/apache/tuscany/runtime/webapp/Constants.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.runtime.webapp;
 
 /**

Modified: incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/test/java/org/apache/tuscany/runtime/webapp/TuscanySessionListenerTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/test/java/org/apache/tuscany/runtime/webapp/TuscanySessionListenerTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/test/java/org/apache/tuscany/runtime/webapp/TuscanySessionListenerTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/runtime/webapp/src/test/java/org/apache/tuscany/runtime/webapp/TuscanySessionListenerTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.runtime.webapp;
 
 import javax.servlet.ServletContext;

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/bindings/binding.celtix/.pmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/bindings/binding.celtix/.pmd?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/bindings/binding.celtix/.pmd (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/bindings/binding.celtix/.pmd Sun Nov 19 08:03:50 2006
@@ -1,2 +1,23 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<pmd><useProjectRuleSet>true</useProjectRuleSet><rules/></pmd>
+<!--
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+-->
+<pmd>
+    <useProjectRuleSet>true</useProjectRuleSet>
+    <rules/>
+</pmd>

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/apache/tuscany/container/spring/impl/SpringInterceptor.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/apache/tuscany/container/spring/impl/SpringInterceptor.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/apache/tuscany/container/spring/impl/SpringInterceptor.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/apache/tuscany/container/spring/impl/SpringInterceptor.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.container.spring.impl;
 
 import org.apache.tuscany.spi.wire.Interceptor;

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/springframework/sca/ScaAdapterAware.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/springframework/sca/ScaAdapterAware.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/springframework/sca/ScaAdapterAware.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/main/java/org/springframework/sca/ScaAdapterAware.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.springframework.sca;
 
 /**

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/impl/SpringCompositeComponentTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/impl/SpringCompositeComponentTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/impl/SpringCompositeComponentTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/impl/SpringCompositeComponentTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.container.spring.impl;
 
 import org.apache.tuscany.spi.component.Service;

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/integration/BootstrapTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/integration/BootstrapTestCase.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/integration/BootstrapTestCase.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/integration/BootstrapTestCase.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.container.spring.integration;
 
 import org.osoa.sca.CompositeContext;

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/mock/TestReference.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/mock/TestReference.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/mock/TestReference.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/containers/container.spring/src/test/java/org/apache/tuscany/container/spring/mock/TestReference.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.container.spring.mock;
 
 /**

Modified: incubator/tuscany/branches/sca-java-M2/sca/services/databinding/databinding-sdo/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/services/databinding/databinding-sdo/pom.xml?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/services/databinding/databinding-sdo/pom.xml (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/services/databinding/databinding-sdo/pom.xml Sun Nov 19 08:03:50 2006
@@ -28,6 +28,21 @@
     <name>Apache Tuscany Data Binding for SDO</name>
     <description>Data Binding based on SDO.</description>
 
+    <!-- include incubator repo as a plugin repo -->
+    <pluginRepositories>
+        <pluginRepository>
+            <id>apache.incubator</id>
+            <name>Apache Incubator Repository</name>
+            <url>http://people.apache.org/repo/m2-incubating-repository/</url>
+            <releases>
+                <enabled>true</enabled>
+            </releases>
+            <snapshots>
+                <enabled>false</enabled>
+            </snapshots>
+        </pluginRepository>
+    </pluginRepositories>
+
     <dependencies>
         <dependency>
             <groupId>org.apache.tuscany.sca.kernel</groupId>

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/Bootstrapper.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/Bootstrapper.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/Bootstrapper.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/Bootstrapper.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test;
 
 import java.net.URL;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingReference.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingReference.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingReference.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingReference.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import org.apache.tuscany.spi.component.CompositeComponent;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingRuntimeException.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingRuntimeException.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingRuntimeException.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestBindingRuntimeException.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import org.apache.tuscany.api.TuscanyRuntimeException;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestInvoker.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestInvoker.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestInvoker.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestInvoker.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import java.lang.reflect.InvocationTargetException;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBinding.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBinding.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBinding.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBinding.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import org.apache.tuscany.spi.model.Binding;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingBuilder.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingBuilder.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingBuilder.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingBuilder.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import org.apache.tuscany.spi.component.CompositeComponent;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingLoader.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingLoader.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingLoader.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingLoader.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import javax.xml.namespace.QName;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingReference.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingReference.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingReference.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingReference.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import org.apache.tuscany.spi.component.CompositeComponent;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingService.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingService.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingService.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketBindingService.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import java.io.IOException;

Modified: incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketInvoker.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketInvoker.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================
--- incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketInvoker.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/test/src/main/java/org/apache/tuscany/test/binding/TestSocketInvoker.java Sun Nov 19 08:03:50 2006
@@ -1,3 +1,21 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
 package org.apache.tuscany.test.binding;
 
 import java.io.IOException;



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/branches/sca-java-M2/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java (original)
+++ incubator/tuscany/branches/sca-java-M2/sca/plugins/plugin.war/src/main/java/org/apache/tuscany/plugin/war/TuscanyWarMojo.java Sun Nov 19 08:03:50 2006
@@ -57,7 +57,8 @@
  * <ul>
  *   <li>Adds the boot dependencies transitively to WEB-INF/tuscany/boot</li>
  *   <li>By default boot libraries are transitively resolved from webapp-host</li>
  *   <li>This can be overridden using the configuration/bootLibs element in the plugin</li>
  *   <li>Adds the extension artifacts specified using configuration/extensions to WEB-INF/tuscany/extensions</li>
  *   <li>If configuration/loadExtensionsDependency is set to true extension dependencies are transitivel loaded</li>
  *   <li>Extension dependencies are loaded into WEB-INF/tuscany/repository directory in a Maven repo format</li>
@@ -172,6 +173,13 @@
     private boolean loadExtensionDependencies;
 
     /**
+     * The default version of boot dependany jar files
+     * 
+     * @parameter
+     */
+    private String runTimeVersion = null;
+    
+    /**
      * WEB-INF jar files.
      */
     private Set<String> packagedLibs = new HashSet<String>();
@@ -195,6 +203,14 @@
 
         try {
 
+        	// if there is a runtime version specified and no bootLib dependancies,
+        	// modify the bootLibs to have the runtime version.
+        	if (runTimeVersion != null && bootLibs == Dependency.getDefaultBootLibs()) {
+        		Dependency dependancy = new Dependency("org.apache.tuscany.sca.runtime", 
+        				"webapp-host", runTimeVersion);
+        		bootLibs = new Dependency[] {dependancy};
+        	}
+        	
             originalWarFile = new File(outputDirectory, warName + ".war");
             originalWar = new JarFile(originalWarFile);
 
@@ -57,7 +57,8 @@
  *   <li>Adds the boot dependencies transitively to WEB-INF/tuscany/boot</li>
  *   <li>By default boot libraries are transitively resolved from webapp-host</li>
- *   <li>This can be overridden using the configuration/bootLibs element in the plugin</li>
+ *   <li>The version of boot libraries can be specified using configuration/runTimeVersion element</li>
+ *   <li>Boot libraries can be overridden using the configuration/bootLibs element in the plugin</li>
  *   <li>Adds the extension artifacts specified using configuration/extensions to WEB-INF/tuscany/extensions</li>
  *   <li>If configuration/loadExtensionsDependency is set to true extension dependencies are transitivel loaded</li>

Modified: incubator/tuscany/branches/sca-java-M2/sca/runtime/osgi/src/main/java/org/apache/tuscany/osgi/util/ClassloaderHook.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/branches/sca-java-M2/sca/runtime/osgi/src/main/java/org/apache/tuscany/osgi/util/ClassloaderHook.java?view=diff&rev=476842&r1=476841&r2=476842
==============================================================================